| Home | Libraries | People | FAQ | More

### is_member_pointer

    template <class T>
    struct is_member_pointer : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) pointer to a member (either a function or a data member) then inherits from true_type, otherwise inherits from false_type.

C++ Standard Reference: 3.9.2 and 8.3.3.

Header: `#include <boost/type_traits/is_member_pointer.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> `is_member_pointer<int (MyClass::*)>` inherits from `true_type`.

> `is_member_pointer<int (MyClass::*)(char)>::type` is the type `true_type`.

> `is_member_pointer<int (MyClass::*)(void)const>::value` is an integral constant expression that evaluates to true.

> `is_member_pointer<T>::value_type` is the type `bool`.